var _dec, _dec2, _class, _AppNav;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { Component } from 'react';
import { withStyle } from '@instructure/emotion';
import { callRenderProp, omitProps } from '@instructure/ui-react-utils';
import { testable } from '@instructure/ui-testable';
import { View } from '@instructure/ui-view';
import { Menu } from '@instructure/ui-menu';
import { Item } from './Item';
import generateStyle from './styles';
import generateComponentTheme from './theme';
import { allowedProps, propTypes } from './props';
import { TruncateList } from '@instructure/ui-truncate-list';

/**
---
category: components
---
**/
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
let AppNav = (_dec = withStyle(generateStyle, generateComponentTheme), _dec2 = testable(), _dec(_class = _dec2(_class = (_AppNav = class AppNav extends Component {
  constructor(...args) {
    super(...args);
    this.state = {
      isMeasuring: false
    };
    this.ref = null;
    this.handleRef = el => {
      const elementRef = this.props.elementRef;
      this.ref = el;
      if (typeof elementRef === 'function') {
        elementRef(el);
      }
    };
  }
  componentDidMount() {
    var _this$props$makeStyle, _this$props;
    (_this$props$makeStyle = (_this$props = this.props).makeStyles) === null || _this$props$makeStyle === void 0 ? void 0 : _this$props$makeStyle.call(_this$props);
  }
  componentDidUpdate() {
    var _this$props$makeStyle2, _this$props2;
    (_this$props$makeStyle2 = (_this$props2 = this.props).makeStyles) === null || _this$props$makeStyle2 === void 0 ? void 0 : _this$props$makeStyle2.call(_this$props2);
  }
  renderMenu(items) {
    return _jsx(Menu, {
      trigger: _jsx(AppNav.Item, {
        renderLabel: callRenderProp(this.props.renderTruncateLabel)
      }),
      children: items.map((item, index) => {
        return _jsx(Menu.Item, {
          href: item.props.href ? item.props.href : void 0,
          onClick: item.props.onClick && !item.props.href ? item.props.onClick : void 0,
          children: callRenderProp(item.props.renderLabel)
        }, index);
      })
    });
  }
  render() {
    const _this$props3 = this.props,
      visibleItemsCount = _this$props3.visibleItemsCount,
      screenReaderLabel = _this$props3.screenReaderLabel,
      margin = _this$props3.margin,
      debounce = _this$props3.debounce,
      styles = _this$props3.styles;
    const passthroughProps = View.omitViewProps(omitProps(this.props, AppNav.allowedProps), AppNav);
    const renderBeforeItems = callRenderProp(this.props.renderBeforeItems);
    const renderAfterItems = callRenderProp(this.props.renderAfterItems);
    const hasRenderedContent = renderBeforeItems || renderAfterItems;
    return _jsxs(View, {
      ...passthroughProps,
      as: "nav",
      css: [styles === null || styles === void 0 ? void 0 : styles.appNav, hasRenderedContent ? styles === null || styles === void 0 ? void 0 : styles.alignCenter : ''],
      margin: margin,
      display: hasRenderedContent ? 'flex' : 'block',
      elementRef: this.handleRef,
      children: [renderBeforeItems && _jsx("span", {
        children: renderBeforeItems
      }), _jsx(TruncateList, {
        visibleItemsCount: visibleItemsCount,
        debounce: debounce,
        onUpdate: this.props.onUpdate,
        renderHiddenItemMenu: hiddenChildren => this.renderMenu(hiddenChildren),
        itemSpacing: styles === null || styles === void 0 ? void 0 : styles.horizontalMargin,
        fixMenuTriggerWidth: styles === null || styles === void 0 ? void 0 : styles.menuTriggerWidth,
        css: styles === null || styles === void 0 ? void 0 : styles.list,
        "aria-label": callRenderProp(screenReaderLabel),
        children: this.props.children
      }), renderAfterItems && _jsx("span", {
        children: renderAfterItems
      })]
    });
  }
}, _AppNav.displayName = "AppNav", _AppNav.componentId = 'AppNav', _AppNav.allowedProps = allowedProps, _AppNav.propTypes = propTypes, _AppNav.defaultProps = {
  children: null,
  debounce: 300,
  margin: '0',
  renderTruncateLabel: () => 'More',
  visibleItemsCount: 0
}, _AppNav.Item = Item, _AppNav)) || _class) || _class);
export { AppNav };
export default AppNav;