"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _ScreenReaderContent2 = require("@instructure/ui-a11y-content/lib/ScreenReaderContent");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _Item, _Item2, _Item3, _ScreenReaderContent;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const icon = (0, _jsxRuntime.jsxs)("svg", {
  height: "24",
  width: "24",
  children: [(0, _jsxRuntime.jsx)("title", {
    children: "Some icon"
  }), (0, _jsxRuntime.jsx)("circle", {
    cx: "50",
    cy: "50",
    r: "40"
  })]
});
describe('<AppNav.Item />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render label text', async () => {
    (0, _react.render)(_Item || (_Item = (0, _jsxRuntime.jsx)(_index.Item, {
      renderLabel: "Some label",
      href: "#"
    })));
    const item = _react.screen.getByRole('link');
    expect(item).toHaveTextContent('Some label');
  });
  it('should render an icon/image/etc.', async () => {
    const _render = (0, _react.render)(_Item2 || (_Item2 = (0, _jsxRuntime.jsx)(_index.Item, {
        renderIcon: icon,
        renderLabel: (0, _jsxRuntime.jsx)(_ScreenReaderContent2.ScreenReaderContent, {
          children: "Some label"
        }),
        href: "#"
      }))),
      container = _render.container;
    const iconTitle = _react.screen.getByTitle('Some icon');
    const iconSvg = container.querySelector('svg');
    const item = _react.screen.getByRole('link');
    expect(iconTitle).toBeInTheDocument();
    expect(iconSvg).toBeInTheDocument();
    expect(iconSvg).toHaveTextContent('Some icon');
    expect(item).toHaveTextContent('Some label');
  });
  it('should render content after the label text to accommodate badges, etc.', async () => {
    (0, _react.render)(_Item3 || (_Item3 = (0, _jsxRuntime.jsx)(_index.Item, {
      renderLabel: "Some label",
      href: "#",
      renderAfter: (0, _jsxRuntime.jsx)("strong", {
        children: "I am rendered after!"
      })
    })));
    const item = _react.screen.getByRole('link');
    const after = _react.screen.getByText('I am rendered after!');
    expect(item).toBeInTheDocument();
    expect(item).toHaveTextContent('Some label');
    expect(after).toBeInTheDocument();
    expect(after.tagName).toBe('STRONG');
  });
  it('should respond to an onClick event', async () => {
    const onClick = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.Item, {
      renderLabel: "Some label",
      onClick: onClick
    }));
    const button = _react.screen.getByRole('button');
    await _userEvent.default.click(button);
    await (0, _react.waitFor)(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
  it('should output a console error if icon is used with non-screenreader label text', async () => {
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.Item, {
      renderIcon: icon,
      renderLabel: "Some label",
      onClick: () => 'clicked'
    }));
    const expectedErrorMessage = 'Warning: [AppNav] If an icon is used, the label text should be wrapped in <ScreenReaderContent />.';
    expect(consoleErrorMock).toHaveBeenCalledWith(expect.stringContaining(expectedErrorMessage), expect.any(String));
  });
  it('should meet a11y standards', async () => {
    const _render2 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.Item, {
        renderIcon: icon,
        renderLabel: _ScreenReaderContent || (_ScreenReaderContent = (0, _jsxRuntime.jsx)(_ScreenReaderContent2.ScreenReaderContent, {
          children: "Some label"
        })),
        onClick: () => 'clicked'
      })),
      container = _render2.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    expect(axeCheck).toBe(true);
  });
});