"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Item = void 0;
var _react = require("react");
var _console = require("@instructure/console");
var _callRenderProp = require("@instructure/ui-react-utils/lib/callRenderProp.js");
var _getElementType = require("@instructure/ui-react-utils/lib/getElementType.js");
var _matchComponentTypes = require("@instructure/ui-react-utils/lib/matchComponentTypes.js");
var _passthroughProps = require("@instructure/ui-react-utils/lib/passthroughProps.js");
var _testable = require("@instructure/ui-testable/lib/testable.js");
var _View = require("@instructure/ui-view/lib/View");
var _ScreenReaderContent = require("@instructure/ui-a11y-content/lib/ScreenReaderContent");
var _emotion = require("@instructure/emotion");
var _styles = _interopRequireDefault(require("./styles"));
var _theme = _interopRequireDefault(require("./theme"));
var _props = require("./props");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _dec, _dec2, _class, _Item;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/**
---
parent: AppNav
id: AppNav.Item
---
@module Item
**/
let Item = exports.Item = (_dec = (0, _emotion.withStyle)(_styles.default, _theme.default), _dec2 = (0, _testable.testable)(), _dec(_class = _dec2(_class = (_Item = class Item extends _react.Component {
  constructor(...args) {
    super(...args);
    this.ref = null;
    this.handleRef = el => {
      const elementRef = this.props.elementRef;
      this.ref = el;
      if (typeof elementRef === 'function') {
        elementRef(el);
      }
    };
    this.handleClick = e => {
      const _this$props = this.props,
        isDisabled = _this$props.isDisabled,
        onClick = _this$props.onClick;
      if (isDisabled) {
        e.preventDefault();
        e.stopPropagation();
      } else if (typeof onClick === 'function') {
        onClick(e);
      }
    };
  }
  componentDidMount() {
    var _this$props$makeStyle, _this$props2;
    (_this$props$makeStyle = (_this$props2 = this.props).makeStyles) === null || _this$props$makeStyle === void 0 ? void 0 : _this$props$makeStyle.call(_this$props2);
  }
  componentDidUpdate() {
    var _this$props$makeStyle2, _this$props3;
    (_this$props$makeStyle2 = (_this$props3 = this.props).makeStyles) === null || _this$props$makeStyle2 === void 0 ? void 0 : _this$props$makeStyle2.call(_this$props3);
  }
  render() {
    var _this$props$styles, _this$props$styles2;
    const ElementType = (0, _getElementType.getElementType)(Item, this.props);
    const _this$props4 = this.props,
      renderIcon = _this$props4.renderIcon,
      renderLabel = _this$props4.renderLabel,
      href = _this$props4.href,
      renderAfter = _this$props4.renderAfter,
      cursor = _this$props4.cursor,
      isDisabled = _this$props4.isDisabled;
    const icon = (0, _callRenderProp.callRenderProp)(renderIcon);
    const label = (0, _callRenderProp.callRenderProp)(renderLabel);
    const labelIsForScreenReaders = (0, _matchComponentTypes.matchComponentTypes)(label, [_ScreenReaderContent.ScreenReaderContent]);
    if (icon) {
      (0, _console.logError)(labelIsForScreenReaders, '[AppNav] If an icon is used, the label text should be wrapped in <ScreenReaderContent />.');
    }
    return (0, _jsxRuntime.jsxs)(_View.View, {
      ...(0, _passthroughProps.passthroughProps)(this.props),
      as: ElementType,
      href: href,
      onClick: this.handleClick,
      disabled: isDisabled,
      elementRef: this.handleRef,
      display: "flex",
      position: "relative",
      borderRadius: "medium",
      cursor: isDisabled ? 'not-allowed' : cursor,
      css: (_this$props$styles = this.props.styles) === null || _this$props$styles === void 0 ? void 0 : _this$props$styles.item,
      children: [icon, labelIsForScreenReaders ? label : (0, _jsxRuntime.jsx)("span", {
        css: (_this$props$styles2 = this.props.styles) === null || _this$props$styles2 === void 0 ? void 0 : _this$props$styles2.label,
        children: label
      }), renderAfter && (0, _callRenderProp.callRenderProp)(renderAfter)]
    });
  }
}, _Item.displayName = "Item", _Item.componentId = 'AppNav.Item', _Item.allowedProps = _props.allowedProps, _Item.propTypes = _props.propTypes, _Item.defaultProps = {
  children: null,
  isSelected: false,
  cursor: 'pointer',
  isDisabled: false
}, _Item)) || _class) || _class);
var _default = exports.default = Item;