"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
require("@testing-library/jest-dom");
var _generateA11yTests = require("@instructure/ui-scripts/lib/test/generateA11yTests");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _index = require("../index");
var _AppNav4 = _interopRequireDefault(require("../__examples__/AppNav.examples"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _AppNav, _AppNav$Item, _AppNav2, _AppNav3, _AppNav$Item2, _AppNav$Item3, _AppNav$Item4, _AppNav$Item5;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
// eslint-disable-next-line no-restricted-imports
describe('<AppNav />', () => {
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleErrorMock.mockRestore();
  });
  describe('for a11y', () => {
    it('should render a nav element with an aria-label', async () => {
      const _render = (0, _react.render)(_AppNav || (_AppNav = (0, _jsxRuntime.jsxs)(_index.AppNav, {
          screenReaderLabel: "Screen reader label",
          visibleItemsCount: 2,
          children: [(0, _jsxRuntime.jsx)(_index.AppNav.Item, {
            renderLabel: "Some label",
            href: "http://instructure.design"
          }), (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
            renderLabel: "Some other label",
            href: "http://instructure.design"
          })]
        }))),
        container = _render.container;
      const appNavList = container.querySelector('ul[class*="-appNav__list"]');
      expect(appNavList).toBeInTheDocument();
      expect(appNavList.tagName).toBe('UL');
      expect(appNavList).toHaveAttribute('aria-label', 'Screen reader label');
    });
    it('should render a semantic list of items', async () => {
      (0, _react.render)((0, _jsxRuntime.jsxs)(_index.AppNav, {
        screenReaderLabel: "App navigation",
        visibleItemsCount: 2,
        children: [_AppNav$Item || (_AppNav$Item = (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Some first label",
          href: "http://instructure.design"
        })), (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Some second label",
          onClick: () => 'clicked'
        })]
      }));
      const list = _react.screen.getAllByRole('list');
      const items = _react.screen.getAllByRole('listitem');
      const link = _react.screen.getAllByRole('link');
      const button = _react.screen.getAllByRole('button');
      expect(list.length).toBe(1);
      expect(items.length).toBe(2);
      expect(link.length).toBe(1);
      expect(button.length).toBe(1);
    });
    it('should render with a single item', async () => {
      (0, _react.render)(_AppNav2 || (_AppNav2 = (0, _jsxRuntime.jsx)(_index.AppNav, {
        screenReaderLabel: "App navigation",
        visibleItemsCount: 1,
        children: (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Some label",
          href: "http://instructure.design"
        })
      })));
      const list = _react.screen.getAllByRole('list');
      const items = _react.screen.getAllByRole('listitem');
      const link = _react.screen.getAllByRole('link');
      expect(list.length).toBe(1);
      expect(items.length).toBe(1);
      expect(link.length).toBe(1);
    });
  });
  describe('with rendered content', () => {
    it('should render content after the navigation', async () => {
      (0, _react.render)(_AppNav3 || (_AppNav3 = (0, _jsxRuntime.jsxs)(_index.AppNav, {
        screenReaderLabel: "App navigation",
        renderAfterItems: (0, _jsxRuntime.jsx)("button", {
          type: "button",
          children: "I am rendered after!"
        }),
        visibleItemsCount: 2,
        children: [(0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Some label",
          href: "http://instructure.design"
        }), (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Some other label",
          href: "http://instructure.design"
        })]
      })));
      const button = _react.screen.getByRole('button');
      expect(button).toHaveTextContent('I am rendered after!');
    });
  });
  describe('with item truncation', () => {
    it('should pass a custom label to the menu trigger', async () => {
      (0, _react.render)((0, _jsxRuntime.jsxs)(_index.AppNav, {
        screenReaderLabel: "App navigation",
        visibleItemsCount: 2,
        renderTruncateLabel: function () {
          return 'I am sooo custom!';
        },
        children: [_AppNav$Item2 || (_AppNav$Item2 = (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Label",
          href: "http://instructure.design"
        })), _AppNav$Item3 || (_AppNav$Item3 = (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Label",
          href: "http://instructure.design"
        })), _AppNav$Item4 || (_AppNav$Item4 = (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Label",
          href: "http://instructure.design"
        })), _AppNav$Item5 || (_AppNav$Item5 = (0, _jsxRuntime.jsx)(_index.AppNav.Item, {
          renderLabel: "Label",
          href: "http://instructure.design"
        }))]
      }));
      const items = _react.screen.getAllByRole('listitem');
      expect(items.length).toBe(3);
      expect(items[2]).toHaveTextContent('I am sooo custom!');
    });
  });
  describe('with generated examples', () => {
    const generatedComponents = (0, _generateA11yTests.generateA11yTests)(_index.AppNav, _AppNav4.default);
    for (const component of generatedComponents) {
      it(component.description, async () => {
        const _render2 = (0, _react.render)(component.content),
          container = _render2.container;
        const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
        expect(axeCheck).toBe(true);
      });
    }
  });
});