import React from 'react';
import type { Spacing, WithStyleProps, ComponentStyle } from '@instructure/emotion';
import type { PropValidators, AppNavTheme, OtherHTMLAttributes } from '@instructure/shared-types';
import { Renderable } from '@instructure/shared-types';
type AppNavOwnProps = {
    /**
     * Screenreader label for the overall navigation
     */
    screenReaderLabel: string;
    /**
     * The rate (in ms) the component responds to container resizing or
     * an update to one of its child items
     */
    debounce?: number;
    /**
     * Content to display before the navigation items, such as a logo
     */
    renderBeforeItems?: Renderable;
    /**
     * Content to display after the navigation items, aligned to the far end
     * of the navigation
     */
    renderAfterItems?: Renderable;
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    /**
     * Provides a reference to the underlying nav element
     */
    elementRef?: (element: Element | null) => void;
    /**
     * Customize the text displayed in the menu trigger when links overflow
     * the overall nav width.
     */
    renderTruncateLabel?: Renderable;
    /**
     * Called whenever the navigation items are updated or the size of
     * the navigation changes. Passes in the `visibleItemsCount` as
     * a parameter.
     */
    onUpdate?: (visibleItemsCount: {
        visibleItemsCount: number;
    }) => void;
    /**
     * Sets the number of navigation items that are visible.
     */
    visibleItemsCount?: number;
    /**
     * Only accepts `AppNav.Item` as children
     */
    children?: React.ReactNode;
};
type PropKeys = keyof AppNavOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type AppNavProps = AppNavOwnProps & WithStyleProps<AppNavTheme, AppNavStyle> & OtherHTMLAttributes<AppNavOwnProps>;
type AppNavStyle = ComponentStyle<'appNav' | 'alignCenter' | 'list'> & {
    horizontalMargin: string;
    menuTriggerWidth: string;
};
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { AppNavProps, AppNavStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map